<?php

namespace Lean\Console\Controller;

use League\Route\Router;

use Picea\Ui\Method\FormHandler;
use Psr\Http\Message\{ ResponseInterface, ServerRequestInterface };

use Notes\Route\Annotation\Object\Route as RouteParam,
    Notes\Route\Annotation\Method\Route,
    Notes\Security\Annotation\Security,
    Notes\Tell\Annotation\Language;

use \Lean\Console\Lib,
    \Lean\Console\Form;

use Picea\Extension\UrlExtension;

use Ulmus\Annotation\Classes\Table,
    Ulmus\Container\AdapterProxy;


/**
 * @Language("lean.storage")
 */
class Storage extends Console {
    use Lib\ConsoleControllerTrait;

    /**
     * @Route("/storage/database", "name" => "lean.console:storage.database")
     */
    public function database(ServerRequestInterface $request, array $arguments) : ResponseInterface
    {
        $connections = $this->container->has(AdapterProxy::class) ? $this->container->get(AdapterProxy::class)->connections : false;
        $migrations = $this->container->has(Lib\DatabaseMigrations::class) ? $this->container->get(Lib\DatabaseMigrations::class) : false;
        $migrations->getEntities();

        $form = new FormHandler($request, new Form\Database($migrations), null);
        $context = $form->context;

        return $this->renderView("lean-console/page/storage/database", get_defined_vars());
    }

    /**
     * @Route("/storage/session", "name" => "lean.console:storage.session")
     */
    public function session(ServerRequestInterface $request, array $arguments) : ResponseInterface
    {
        $path = ini_get("session.save_path");

        $sessions = preg_grep("/^sess_/", scandir($path));

        return $this->renderView("lean-console/page/storage/session", get_defined_vars());
    }

    /**
     * #Taxus('admin')
     * @Route("/storage/session/content/{hash}", "name" => "lean.console:storage.session_content")
     */
    public function sessionContent(ServerRequestInterface $request, array $arguments) : ResponseInterface
    {
        $sess = session_encode();

        session_decode(file_get_contents($this->sessionPath() . $arguments['hash']));

        $data = array_combine(array_keys($_SESSION), array_values($_SESSION));

        session_decode($sess);

        return $this->renderJson($data);
    }

    protected function sessionPath() : string
    {
        return rtrim(ini_get("session.save_path"), DIRECTORY_SEPARATOR) . DIRECTORY_SEPARATOR;
    }

    public function createTable() : void
    {
        foreach($migrations->entities as $table) {
//            $repository = $table
            // $entity::repository()->createTable();
        }
    }
}